<?php

namespace Drupal\content_export_csv\Form;

use Drupal\content_export_csv\ContentExport;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StreamWrapper\PrivateStream;
use Drupal\Core\StreamWrapper\PublicStream;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Content export form.
 */
class ContentExportForm extends FormBase {

  /**
   * The content export service.
   *
   * @var \Drupal\content_export_csv\ContentExport
   */
  protected $contentExport;

  /**
   * The constructor.
   *
   * @param \Drupal\content_export_csv\ContentExport $content_export
   *   The content export service.
   */
  public function __construct(ContentExport $content_export) {
    $this->contentExport = $content_export;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('content_export_csv.export')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_export_csv_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['content_export'] = [
      '#title' => $this->t('Export options'),
      '#type' => 'fieldset',
    ];

    $form['content_export']['content_type'] = [
      '#title' => $this->t('Content Type'),
      '#type' => 'select',
      '#empty_option' => $this->t('- Select -'),
      '#options' => $this->contentExport->getContentTypes(),
      '#required' => TRUE,
    ];

    $form['content_export']['export'] = [
      '#value' => $this->t('Export content'),
      '#type' => 'submit',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $nodeType = $form_state->getValue('content_type');
    $csvData = $this->contentExport->getNodeCsvData($nodeType);

    $private_path = PrivateStream::basepath();
    $public_path = PublicStream::basepath();
    $file_base = ($private_path) ? $private_path : $public_path;
    $filename = 'content_export' . time() . '.csv';
    $filepath = $file_base . '/' . $filename;
    $csvFile = fopen($filepath, "w");
    $fieldNames = implode(',', $this->contentExport->getValidFieldList($nodeType));

    fwrite($csvFile, $fieldNames . "\n");
    foreach ($csvData as $csvDataRow) {
      fwrite($csvFile, $csvDataRow . "\n");
    }
    fclose($csvFile);

    header('Content-Type: text/csv');
    header('Content-Disposition: attachment; filename="' . basename($filepath) . '";');
    header('Content-Length: ' . filesize($filepath));
    readfile($filepath);
    unlink($filepath);
    exit;
  }

}
